// ========================================
// Watering can / Arrosoir
// -----------------------------------------
// Made for Persistence of vision 3.6
//==========================================  
// Copyright 2007 Gilles Tran http://www.oyonale.com
// -----------------------------------------
// This work is licensed under the Creative Commons Attribution License. 
// To view a copy of this license, visit http://creativecommons.org/licenses/by/3.0/ 
// or send a letter to Creative Commons, 559 Nathan Abbott Way, Stanford, California 94305, USA.
// You are free:
// - to copy, distribute, display, and perform the work
// - to make derivative works
// - to make commercial use of the work
// Under the following conditions:
// - Attribution. You must give the original author credit.
// - For any reuse or distribution, you must make clear to others the license terms of this work.
// - Any of these conditions can be waived if you get permission from the copyright holder.
// Your fair use and other rights are in no way affected by the above. 
//========================================== 
// Render with +W800 +H600
// no antialiasing needed if the focal blur is turned on
#version 3.6;
 
#include "colors.inc"

#declare FocalBlurOK=1;
#declare RadOK=1; // no radiosity
#declare AreaOK=1;
global_settings {
    assumed_gamma 1 // adapt is image is too light or too dark (see your display_gamma)
    max_trace_level 30
    #if (RadOK>0)
        radiosity{
            count 200 
            error_bound 0.5
            recursion_limit 2    // CHANGE
            low_error_factor 1  // leave this
            gray_threshold 0   // leave this
            minimum_reuse 0.015  // leave this
            brightness 0.5         // leave this
            adc_bailout 0.01/2   // CHANGE - use adc_bailo        
            normal on
        }
    #end
}

camera{
    location  <0,40, -110> // position of camera <X Y Z>
    direction 4*z            // which way are we looking <X Y Z> & zoom
    up        y                // which way is +up <X Y Z>
    right     image_width/image_height*x            // which way is +right <X Y Z> and aspect ratio
    look_at   y*10-x*5 // point center of view at this point <X Y Z>
    #if (FocalBlurOK=1)
            aperture 2           // [0...N] larger is narrower depth of field (blurrier)
            blur_samples 200        // number of rays per pixel for sampling
            focal_point <0,0,10>    // point that is in focus <X,Y,Z>
            confidence 0.95           // [0...<1] when to move on while sampling (smaller is less accurate)
            variance 1/200            // [0...1] how precise to calculate (smaller is more accurate)
    #end

}


light_source {
    -z*1000
    color rgb <255,230,200>*2/255
    #if (AreaOK=1)
        area_light 10*z,10*y, 5,5 adaptive 1 jitter orient circular
    #end
    rotate x*30
    rotate y*140
}
sphere{
    0,2000
    texture{
        pigment{image_map{jpeg "sky" map_type 1}}
        finish{ambient 2 diffuse 0}
    }
    no_shadow
}
#declare T_Rust=texture{
    pigment{image_map{jpeg "rust"}}
    normal{bump_map{jpeg "rust"} bump_size 2}
    finish{ambient 0 diffuse 1 specular 1 roughness 1/30}
    scale <1.33,1,1>
}
#declare T_Ground=texture{
    pigment{image_map{jpeg "ground"}}
    normal{bump_map{jpeg "ground"} bump_size 1}
    finish{ambient 0 diffuse 1}
    scale <1.33,1,1>*100
    rotate x*90
}

#declare T_Mouth = texture{
    pigment{
        leopard
        pigment_map{
            [0.2 image_map{jpeg "rust"} scale 100]
            [0.2 color Black]
        }
        scale 0.01
        scale <1,2,1>
    }
    finish{ambient 0 diffuse 1 specular 1 roughness 1/30}
}  

#declare T_Mouth1 = texture{T_Rust}
#declare T_Bolt = texture{T_Rust}
#declare T_Body = texture{T_Rust}
#declare T_Pipe1 = texture{T_Rust scale <4,1,1>}
#declare T_Pipe2 = texture{T_Rust scale <1,1,1>}
#declare T_HandleBack = texture{T_Rust scale 5}
#declare T_HandleTop = texture{T_Rust scale 5}

#include "wateringcan.inc"
object{WateringCan rotate -y*125 translate z*10}
plane{y,0 texture{T_Ground} translate z*-20+x*20}

